@@ -4,6 +4,7 @@
 *
 * Changes:
 *   12/30/04   DGP   Hacked from S709 arith. routines.
+*   03/15/05   DGP   Added dblprecision parm to ibm_strtod.
 *	
 ***********************************************************************/
 
@@ -32,4 +33,4 @@ int ibm_dfadd (t_uint64 *, t_uint64 *, int);
 int ibm_dfmpy (t_uint64 *, t_uint64 *, int);
 int ibm_dfdiv (t_uint64 *, t_uint64 *);
 
-int ibm_strtod (char *, t_uint64 *);
+int ibm_strtod (char *, t_uint64 *, int);
